@@ -25,7 +25,7 @@ class ProducerChannel:
         self._channel = self._connection.channel()
 
     def __enter__(self):
-        return self
+        return self._channel
 
     def __exit__(self, type:Any, value:Any, traceback:Any):
         self._channel.close()
